summaryrefslogtreecommitdiffstats
path: root/mbbsd/chc.c
diff options
context:
space:
mode:
authorptt <ptt@63ad8ddf-47c3-0310-b6dd-a9e9d9715204>2004-04-26 23:28:24 +0800
committerptt <ptt@63ad8ddf-47c3-0310-b6dd-a9e9d9715204>2004-04-26 23:28:24 +0800
commit4b502e05397babe1c8050adb99c2f3e1ebcce641 (patch)
tree728b6c056cdbb67dc8579b5d789a967c1ad9858e /mbbsd/chc.c
parentc144625766bb0db3b3f0bc5718fbe55d356e449f (diff)
parenta08baf738de7959e912f5b12314da85eaea5a3c9 (diff)
downloadpttbbs-4b502e05397babe1c8050adb99c2f3e1ebcce641.tar
pttbbs-4b502e05397babe1c8050adb99c2f3e1ebcce641.tar.gz
pttbbs-4b502e05397babe1c8050adb99c2f3e1ebcce641.tar.bz2
pttbbs-4b502e05397babe1c8050adb99c2f3e1ebcce641.tar.lz
pttbbs-4b502e05397babe1c8050adb99c2f3e1ebcce641.tar.xz
pttbbs-4b502e05397babe1c8050adb99c2f3e1ebcce641.tar.zst
pttbbs-4b502e05397babe1c8050adb99c2f3e1ebcce641.zip
simplify thread() i_read() git-svn-id: http://opensvn.csie.org/pttbbs/branches/Ptt.read@1862 63ad8ddf-47c3-0310-b6dd-a9e9d9715204
Diffstat (limited to 'mbbsd/chc.c')
-rw-r--r--mbbsd/chc.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/mbbsd/chc.c b/mbbsd/chc.c
index 17cda17e..d80cf276 100644
--- a/mbbsd/chc.c
+++ b/mbbsd/chc.c
@@ -49,7 +49,7 @@ static const char *chess_brd[BRD_ROW * 2 - 1] = {
"�u�w�q�w�q�w�q�w�q�w�q�w�q�w�q�w�t", /* 3 */
"�x �x �x �x �x �x �x �x �x",
"�u�w�r�w�r�w�r�w�r�w�r�w�r�w�r�w�t", /* 4 */
- "�x �� �F �� �� �j �D �x",
+ "�x �� �e �~ �� �x",
"�u�w�s�w�s�w�s�w�s�w�s�w�s�w�s�w�t", /* 5 */
"�x �x �x �x �x �x �x �x �x",
"�u�w�q�w�q�w�q�w�q�w�q�w�q�w�q�w�t", /* 6 */
@@ -575,14 +575,14 @@ hisplay(int s, chcusr_t *user1, chcusr_t *user2, board_t board, board_t tmpbrd)
if (chc_lefttime < 0) {
chc_lefttime = 0;
/* to make him break out igetkey() */
chc_from.r = -2;
chc_broadcast_send(act_list, board);
}
chc_drawline(board, user1, user2, TIME_ROW);
move(1, 0);
oflush();
- switch (igetkey()) {
+ switch (igetch()) {
case 'q':
endgame = 2;
endturn = 1;
@@ -653,7 +653,7 @@ myplay(int s, chcusr_t *user1, chcusr_t *user2, board_t board, board_t tmpbrd)
chc_drawline(board, user1, user2, TIME_ROW);
chc_movecur(chc_cursor.r, chc_cursor.c);
oflush();
- ch = igetkey();
+ ch = igetch();
chc_lefttime = CHC_TIMEOUT - (now - start_time);
if (chc_lefttime < 0)
ch = 'q';
@@ -575,14 +575,14 @@ hisplay(int s, chcusr_t *user1, chcusr_t *user2, board_t board, board_t tmpbrd)
if (chc_lefttime < 0) {
chc_lefttime = 0;
- /* to make him break out igetkey() */
+ /* to make him break out igetch() */
chc_from.r = -2;
chc_broadcast_send(act_list, board);